2022-04-21 Version: 1.0.2
- Some APIs are changed to invisiable.
- Wrong type of SenderStatisticsDetailByParam reponse fields is fixed.

2022-04-13 Version: 1.0.1
- Some APIs are changed to invisiable.
- Wrong type of QueryInvalidAddress reponse fields is fixed.

